from data_send import  send
from models.project_data import SubProjectModel,SubProjectItemModel


def send_project_data(project: SubProjectModel) -> bool:
    """
    发送项目数据到平台
    :param project
    """
    return send.DataSend().send_by_project(project)

def send_item_data_by_id(item_id: int) -> bool:
    """
    发送项目数据到平台
    :param item_id
    """
    return send.DataSend().send_by_item_id(item_id)
def send_item_data(item: SubProjectItemModel) -> bool:
    """
    发送项目数据到平台
    :param item
    """
    return send.DataSend().send_by_item(item)